# GAIuS™ Python SDK
A Python SDK for Intelligent Artifacts' GAIuS™ agents.

## What is GAIuS™?
GAIuS™ is an Artificial General Intelligence framework for rapidly building machine intelligence solutions for any problem domain.

## What is IA's Python SDK?
This package, ia-sdk-python, is a software development kit for interacting with IA's GAIuS agents from Python.  It provides useful tools and services.

## Install
`pip install ia-sdk`

Provides:

    - GenomeInfo
    - AgentClient
    - PerformanceValidationTest
    - Higher Level Agent Operations
    - Utilities for interacting with the GAIuS Framework

## Documentation

Detailed documentation for the Python SDK can be found at [this site](http://intelligent-artifacts.bitbucket.io)
